@@ -294,14 +294,7 @@ impl Api {
         P: fmt::Display,
         T: de::DeserializeOwned + ser::Serialize + fmt::Debug,
     {
-        let url = self.url(path);
-        self.client()?
-            .get(url)
-            .optionally_bearer_auth(self.token.as_ref())
-            .inspect()
-            .retry()
-            .await?
-            .error_for_status2()
+        self.get_impl(path)
             .await?
             .try_into()
             .inspect(|output| self.inspect(output))
@@ -370,6 +363,21 @@ impl Api {
             .user_agent(&self.user_agent)
             .build()
     }
+
+    async fn get_impl<P>(&self, path: P) -> anyhow::Result<bytes::Bytes>
+    where
+        P: fmt::Display,
+    {
+        let url = self.url(path);
+        self.client()?
+            .get(url)
+            .optionally_bearer_auth(self.token.as_ref())
+            .inspect()
+            .retry()
+            .await?
+            .error_for_status2()
+            .await
+    }
 }
 
 trait Optionally {
