@@ -3,8 +3,6 @@
 // Use is subject to license terms.
 //
 
-use serde::{de, ser};
-
 use super::*;
 
 const GITLAB_STATEHUB_GENERIC_PACKAGES: &str = "/projects/25498479/packages/generic";
@@ -13,9 +11,13 @@ const GITLAB_STATEHUB_GENERIC_PACKAGES: &str = "/projects/25498479/packages/gene
 pub(crate) trait GitlabGenericPackage {
     const BASE_URL: &'static str;
     const API_VERSION: &'static str;
-    async fn get_file<T>(&self, package: &str, version: &str, file: &str) -> anyhow::Result<T>
-    where
-        T: fmt::Debug + ser::Serialize + de::DeserializeOwned;
+    async fn get_file(
+        &self,
+        package: &str,
+        version: &str,
+        file: &str,
+    ) -> anyhow::Result<bytes::Bytes>;
+
     fn gitlab() -> Self;
 }
 
@@ -24,16 +26,18 @@ impl GitlabGenericPackage for Api {
     const BASE_URL: &'static str = "https://gitlab.com";
     const API_VERSION: &'static str = "/api/v4";
 
-    async fn get_file<T>(&self, package: &str, version: &str, file: &str) -> anyhow::Result<T>
-    where
-        T: fmt::Debug + ser::Serialize + de::DeserializeOwned,
-    {
+    async fn get_file(
+        &self,
+        package: &str,
+        version: &str,
+        file: &str,
+    ) -> anyhow::Result<bytes::Bytes> {
         let path = format!(
             "{}/{}/{}/{}",
             GITLAB_STATEHUB_GENERIC_PACKAGES, package, version, file,
         );
 
-        self.get(path).await.map(Output::into_inner)
+        self.get_impl(path).await
     }
 
     fn gitlab() -> Self {
