@@ -4,6 +4,7 @@
 //
 
 use std::collections::hash_map::DefaultHasher;
+use std::env;
 use std::hash::{Hash, Hasher};
 
 use console::Emoji;
@@ -47,7 +48,11 @@ const STATE_LABELS: &[Emoji<'static, 'static>] = &[
 ];
 
 pub(crate) fn get_label(text: &str) -> Emoji<'static, 'static> {
-    let idx = hash(text) as usize % STATE_LABELS.len();
+    let idx = if env::var("SHFUN").is_ok() {
+        hash(text) as usize % STATE_LABELS.len()
+    } else {
+        0
+    };
     STATE_LABELS[idx]
 }
 
