@@ -331,7 +331,7 @@ or run following commands before running 'statehub register-cluster`
             latest
         );
 
-        if latest > current {
+        if current < latest {
             Some((current, latest))
         } else {
             None
