@@ -365,6 +365,7 @@ impl Cli {
 
         let statehub = StateHub::new(config, self.json, self.verbose);
 
+        statehub.check_for_update().await;
         statehub.validate_auth().await?;
 
         match self.command {
@@ -897,14 +898,20 @@ impl StateHub {
         })
     }
 
+    async fn check_for_update(&self) {
+        self.check_for_update_helper()
+            .await
+            .and_then(|(current, latest)| {
+                self.inform(format_args!(
+                    "\nNewer version '{}' is available (you have '{}')\n",
+                    latest, current
+                ))
+                .ok()
+            });
+    }
+
     async fn self_update(&self) -> anyhow::Result<()> {
         if let Some((current, latest)) = self.check_for_update_helper().await {
-            self.inform(format_args!(
-                "Newer version {} is available (you have {})",
-                latest, current
-            ))
-            .context("Checking for latest release")?;
-
             if current < latest {
                 self.update_helper(latest).await?;
             }
